@@ -2,8 +2,6 @@
 #include <mach/imx-flash-header.h>
 #include <asm/barebox-arm-head.h>
 
-extern unsigned long _stext;
-
 void __naked __flash_header_start go(void)
 {
 	barebox_arm_head();
@@ -82,4 +80,4 @@ struct imx_flash_header __flash_header_section flash_header = {
 	.dcd_block_len		= sizeof (dcd_entry),
 };
 
-unsigned long __image_len_section barebox_len = 0x40000;
+unsigned long __image_len_section barebox_len = DCD_BAREBOX_SIZE;
