@@ -129,13 +129,13 @@ static int pcaaxl2_devices_init(void)
 
 #ifdef CONFIG_PARTITION
 	devfs_add_partition("nand0", 0x00000, SZ_128K,
-			PARTITION_FIXED, "xload_raw");
+			DEVFS_PARTITION_FIXED, "xload_raw");
 	dev_add_bb_dev("xload_raw", "xload");
 	devfs_add_partition("nand0", SZ_128K, SZ_256K,
-			PARTITION_FIXED, "self_raw");
+			DEVFS_PARTITION_FIXED, "self_raw");
 	dev_add_bb_dev("self_raw", "self0");
 	devfs_add_partition("nand0", SZ_128K + SZ_256K, SZ_128K,
-			PARTITION_FIXED, "env_raw");
+			DEVFS_PARTITION_FIXED, "env_raw");
 	dev_add_bb_dev("env_raw", "env0");
 #endif
 
