@@ -40,8 +40,8 @@ static int generic_devices_init(void)
 	register_device(&mac_dev);
 	/*register_device(&epcs_flash_device);*/
 
-	devfs_add_partition("nor0", 0x00000, 0x40000, PARTITION_FIXED, "self0");
-	devfs_add_partition("nor0", 0x40000, 0x20000, PARTITION_FIXED, "env0");
+	devfs_add_partition("nor0", 0x00000, 0x40000, DEVFS_PARTITION_FIXED, "self0");
+	devfs_add_partition("nor0", 0x40000, 0x20000, DEVFS_PARTITION_FIXED, "env0");
 
 	protect_file("/dev/env0", 1);
 
