@@ -214,7 +214,7 @@ static ssize_t m25p80_erase(struct cdev *cdev, size_t count, unsigned long offse
 
 	start_sector = offset / flash->erasesize;
 	end_sector = (offset + count - 1) / flash->erasesize;
-	init_progression_bar(end_sector - start_sector);
+	init_progression_bar(end_sector - start_sector + 1);
 
 	/* whole-chip erase? */
 	if (len == flash->size) {
@@ -232,12 +232,16 @@ static ssize_t m25p80_erase(struct cdev *cdev, size_t count, unsigned long offse
 	/* "sector"-at-a-time erase */
 	} else {
 		while (len) {
+			if (ctrlc())
+				return -EINTR;
 			if (erase_sector(flash, addr))
 				return -EIO;
 
+			show_progress(++progress);
+			if (len <= flash->erasesize)
+				break;
 			addr += flash->erasesize;
 			len -= flash->erasesize;
-			show_progress(progress++);
 		}
 	}
 
