@@ -1,5 +1,10 @@
 
-#if defined CONFIG_ARCH_IMX25 || defined CONFIG_ARCH_IMX35 || defined CONFIG_ARCH_IMX51 || defined CONFIG_ARCH_IMX53 || defined CONFIG_X86
+#if defined CONFIG_ARCH_IMX25 || \
+	defined CONFIG_ARCH_IMX35 || \
+	defined CONFIG_ARCH_IMX51 || \
+	defined CONFIG_ARCH_IMX53 || \
+	defined CONFIG_ARCH_IMX6 || \
+	defined CONFIG_X86
 #include <mach/barebox.lds.h>
 #endif
 
