@@ -3,9 +3,6 @@
 
 struct device_d;
 
-#define PARTITION_FIXED		(1 << 0)
-#define PARTITION_READONLY	(1 << 1)
-
 struct partition {
         int num;
 
